@@ -24,16 +24,8 @@
 
 #include "scim_skk_core.h"
 #include "conv_table.h"
-#include "scim_skk_dictionary.h"
 
-extern SKKDictionary *scim_skkdict;
-extern bool annot_view;
-extern bool annot_pos;
-
-extern bool annot_highlight;
-extern int annot_bgcolor;
-
-extern bool ignore_return;
+using namespace scim_skk;
 
 static void convert_char_to_wide         (const int c,
                                           WideString &result,
@@ -45,8 +37,10 @@ static void convert_hiragana_to_katakana (const WideString &hira,
 static int skk_key_mask = SCIM_KEY_ControlMask | SCIM_KEY_AltMask;
 
 
-SKKCore::SKKCore      (KeyBind *keybind, SKKAutomaton *key2kana)
+SKKCore::SKKCore      (KeyBind *keybind, SKKAutomaton *key2kana,
+                       SKKDictionary *dict)
     : m_keybind(keybind),
+      m_dict(dict),
       m_skk_mode(SKK_MODE_HIRAGANA),
       m_input_mode(INPUT_MODE_DIRECT),
       m_key2kana(key2kana),
@@ -158,7 +152,8 @@ SKKCore::get_preedit_string (WideString &result)
         if (!m_okuristr.empty()) {
             result += m_okuristr;
         }
-        if (annot_view && annot_pos && !m_ltable.visible_table()) {
+        if (annot_view && annot_pos &&
+            !m_ltable.visible_table()) {
             WideString annot = m_ltable.get_annot_from_vector();
             if (annot.length() > 0) {
                 result += utf8_mbstowcs(";");
@@ -211,10 +206,10 @@ SKKCore::commit_or_preedit (const WideString &str)
         m_okuristr += str;
         if (m_pendingstr.empty()) {
             m_ltable.clear();
-            scim_skkdict->lookup(m_preeditstr+m_okurihead, true, m_ltable);
+            m_dict->lookup(m_preeditstr+m_okurihead, true, m_ltable);
             if (m_ltable.empty()) {
                 set_input_mode(INPUT_MODE_LEARNING);
-                m_learning = new SKKCore(m_keybind, m_key2kana);
+                m_learning = new SKKCore(m_keybind, m_key2kana, m_dict);
             } else {
                 set_input_mode(INPUT_MODE_CONVERTING);
             }
@@ -238,13 +233,12 @@ void
 SKKCore::commit_converting (int index)
 {
     if (!m_ltable.vector_empty() && !m_ltable.visible_table()) {
-        WideString str = m_ltable.get_cand_from_vector();
-        commit_string(str);
+        CandEnt cent = m_ltable.get_candent_from_vector();
+        commit_string(cent.cand);
         commit_string(m_okuristr);
         if (m_okurihead != 0)
             m_preeditstr += m_okurihead;
-        scim_skkdict->write(m_preeditstr,
-                            make_pair(str, m_ltable.get_annot_from_vector()));
+        m_dict->write(m_preeditstr, cent);
         m_ltable.clear();
         clear_preedit();
         if (m_skk_mode == SKK_MODE_ASCII)
@@ -257,11 +251,12 @@ SKKCore::commit_converting (int index)
         }
         WideString cand  = m_ltable.get_cand(index);
         WideString annot = m_ltable.get_annot(index);
+        WideString cand_orig = m_ltable.get_cand_orig(index);
         commit_string(cand);
         commit_string(m_okuristr);
         if (m_okurihead != 0)
             m_preeditstr += m_okurihead;
-        scim_skkdict->write(m_preeditstr, make_pair(cand, annot));
+        m_dict->write(m_preeditstr, cand);
         m_ltable.clear();
         clear_preedit();
         if (m_skk_mode == SKK_MODE_ASCII)
@@ -527,15 +522,15 @@ SKKCore::action_convert (void)
         retval = action_nextpage();
         if (!retval) {
             set_input_mode(INPUT_MODE_LEARNING);
-            m_learning = new SKKCore(m_keybind, m_key2kana);
+            m_learning = new SKKCore(m_keybind, m_key2kana, m_dict);
         }
         return true;
     case INPUT_MODE_PREEDIT:
         clear_pending();
-        scim_skkdict->lookup(m_preeditstr, false, m_ltable);
+        m_dict->lookup(m_preeditstr, false, m_ltable);
         if (m_ltable.empty()) {
             set_input_mode(INPUT_MODE_LEARNING);
-            m_learning = new SKKCore(m_keybind, m_key2kana);
+            m_learning = new SKKCore(m_keybind, m_key2kana, m_dict);
         } else {
             set_input_mode(INPUT_MODE_CONVERTING);
         }
@@ -787,7 +782,7 @@ SKKCore::action_forward (void)
         if (m_ltable.visible_table()) {
             if (!m_ltable.cursor_down()) {
                 set_input_mode(INPUT_MODE_LEARNING);
-                m_learning = new SKKCore(m_keybind, m_key2kana);
+                m_learning = new SKKCore(m_keybind, m_key2kana, m_dict);
             }
             return true;
         } else {
@@ -1211,13 +1206,25 @@ SKKCore::process_key_event (const KeyEvent key)
                 retval = true;
             } else {
                 /* learning is committed */
-                commit_string(m_learning->m_commitstr);
+                static const ucs4_t sharp = 0x23; /* code for number sign */
+                if (m_learning->m_commitstr.find(sharp) != WideString::npos) {
+                    WideString result, keystr;
+                    std::list<WideString> numbers;
+                    m_dict->extract_numbers(m_preeditstr,
+                                            numbers, keystr);
+                    m_dict->number_conversion(numbers,
+                                              m_learning->m_commitstr,
+                                              result);
+                    m_preeditstr.assign(keystr);
+                    commit_string(result);
+                } else {
+                    commit_string(m_learning->m_commitstr);
+                }
                 commit_string(m_okuristr);
                 if (m_okurihead != 0)
                     m_preeditstr += m_okurihead;
-                scim_skkdict->write(m_preeditstr,
-                                    make_pair(m_learning->m_commitstr,
-                                              WideString()));
+                m_dict->write(m_preeditstr,
+                              CandEnt(m_learning->m_commitstr));
                 clear_preedit();
                 m_ltable.clear();
                 m_learning->clear();
@@ -1259,7 +1266,10 @@ SKKCore::get_lookup_table (void)
 bool
 SKKCore::lookup_table_visible (void)
 {
-    return m_ltable.visible_table();
+    if (m_learning)
+        return m_learning->lookup_table_visible();
+    else
+        return m_ltable.visible_table();
 }
 
 static void
@@ -1271,9 +1281,9 @@ convert_char_to_wide (const int c, WideString & wide, bool space)
     char cc[2]; cc[0] = c; cc[1] = '\0';
     bool found = false;
 
-    for (unsigned int i = 0; ja_wide_table[i].code; i++) {
-        if (ja_wide_table[i].code && *ja_wide_table[i].code == c) {
-            wide += utf8_mbstowcs (ja_wide_table[i].wide);
+    for (unsigned int i = 0; wide_table[i].code; i++) {
+        if (wide_table[i].code && *wide_table[i].code == c) {
+            wide += utf8_mbstowcs (wide_table[i].wide);
             found = true;
             break;
         }
@@ -1299,13 +1309,13 @@ convert_hiragana_to_katakana (const WideString & hira, WideString & kata,
         WideString tmpwide;
         bool found = false;
 
-        for (unsigned int j = 0; ja_hiragana_katakana_table[j].hiragana; j++) {
-            tmpwide = utf8_mbstowcs (ja_hiragana_katakana_table[j].hiragana);
+        for (unsigned int j = 0; hiragana_katakana_table[j].hiragana; j++) {
+            tmpwide = utf8_mbstowcs (hiragana_katakana_table[j].hiragana);
             if (hira.substr(i, 1) == tmpwide) {
                 if (half)
-                    kata += utf8_mbstowcs (ja_hiragana_katakana_table[j].half_katakana);
+                    kata += utf8_mbstowcs (hiragana_katakana_table[j].half_katakana);
                 else
-                    kata += utf8_mbstowcs (ja_hiragana_katakana_table[j].katakana);
+                    kata += utf8_mbstowcs (hiragana_katakana_table[j].katakana);
                 found = true;
                 break;
             }
