@@ -35,20 +35,10 @@
 #include "scim_skk_imengine.h"
 #include "scim_skk_prefs.h"
 #include "conv_table.h"
+#include "scim_skk_intl.h"
+#include "scim_skk_config.h"
 
-#include <string.h>
-
-#ifdef HAVE_GETTEXT
-#include <libintl.h>
-#define _(String) dgettext(GETTEXT_PACKAGE,String)
-#define N_(String) (String)
-#else
-#define _(String) (String)
-#define N_(String) (String)
-#define bindtextdomain(Package,Directory)
-#define textdomain(domain)
-#define bind_textdomain_codeset(domain,codeset)
-#endif
+using namespace scim_skk;
 
 #define scim_module_init skk_LTX_scim_module_init
 #define scim_module_exit skk_LTX_scim_module_exit
@@ -70,9 +60,10 @@
 #endif
 
 
-
 static ConfigPointer  _scim_config (0);
-SKKDictionary *scim_skkdict = 0;
+static SKKDictionary *scim_skkdict = 0;
+
+
 
 extern "C" {
     void scim_module_init (void)
@@ -120,22 +111,6 @@ extern "C" {
 }
 
 
-bool annot_view = SCIM_SKK_CONFIG_ANNOT_VIEW_DEFAULT;
-/* view annotation if true */
-bool annot_pos =
-  (strncmp(SCIM_SKK_CONFIG_ANNOT_POS_DEFAULT, "inline", 6) == 0);
-/* inline if true, auxwindow if otherwise */
-bool annot_target
-  (strncmp(SCIM_SKK_CONFIG_ANNOT_TARGET_DEFAULT, "all", 3) == 0);
-/* all if true, caret position otherwise */
-int candvec_size = SCIM_SKK_CONFIG_CANDVEC_SIZE_DEFAULT;
-
-bool annot_highlight = SCIM_SKK_CONFIG_ANNOT_HIGHLIGHT_DEFAULT;
-int annot_bgcolor = strtol(SCIM_SKK_CONFIG_ANNOT_BGCOLOR_DEFAULT+1,
-                           (char**)NULL, 16);
-
-bool ignore_return = SCIM_SKK_CONFIG_IGNORE_RETURN_DEFAULT;
-
 SKKFactory::SKKFactory (const String &lang,
                         const String &uuid,
                         const ConfigPointer &config)
@@ -221,10 +196,12 @@ SKKFactory::reload_config (const ConfigPointer &config)
         m_userdictname = config->read(String(SCIM_SKK_CONFIG_USERDICT),
                                       String(SCIM_SKK_CONFIG_USERDICT_DEFAULT));
         scim_skkdict->set_userdict(m_userdictname);
-        candvec_size = config->read(String(SCIM_SKK_CONFIG_CANDVEC_SIZE),
-                                    SCIM_SKK_CONFIG_CANDVEC_SIZE_DEFAULT);
-        annot_view = config->read(String(SCIM_SKK_CONFIG_ANNOT_VIEW),
-                                  SCIM_SKK_CONFIG_ANNOT_VIEW_DEFAULT);
+        candvec_size =
+            config->read(String(SCIM_SKK_CONFIG_CANDVEC_SIZE),
+                         SCIM_SKK_CONFIG_CANDVEC_SIZE_DEFAULT);
+        annot_view =
+            config->read(String(SCIM_SKK_CONFIG_ANNOT_VIEW),
+                         SCIM_SKK_CONFIG_ANNOT_VIEW_DEFAULT);
         str = config->read(String(SCIM_SKK_CONFIG_ANNOT_POS),
                            String(SCIM_SKK_CONFIG_ANNOT_POS_DEFAULT));
         annot_pos = (str == String("inline"));
@@ -239,8 +216,9 @@ SKKFactory::reload_config (const ConfigPointer &config)
                            String(SCIM_SKK_CONFIG_ANNOT_BGCOLOR_DEFAULT));
         annot_bgcolor = strtol(str.c_str() + 1, (char**)NULL, 16);
 
-        ignore_return = config->read(String(SCIM_SKK_CONFIG_IGNORE_RETURN),
-                                     SCIM_SKK_CONFIG_IGNORE_RETURN_DEFAULT);
+        ignore_return =
+            config->read(String(SCIM_SKK_CONFIG_IGNORE_RETURN),
+                         SCIM_SKK_CONFIG_IGNORE_RETURN_DEFAULT);
 
         str = config->read(String(SCIM_SKK_CONFIG_KAKUTEI_KEY),
                            String(SCIM_SKK_CONFIG_KAKUTEI_KEY_DEFAULT));
@@ -306,7 +284,7 @@ SKKInstance::SKKInstance (SKKFactory   *factory,
                           int           id)
     : IMEngineInstanceBase (factory, encoding, id),
       m_skk_mode (SKK_MODE_HIRAGANA),
-      m_skkcore (&(factory->m_keybind), &(m_key2kana))
+      m_skkcore (&(factory->m_keybind), &(m_key2kana), scim_skkdict)
 {
     SCIM_DEBUG_IMENGINE(1) << "Create SKK Instance : ";
     init_key2kana();
@@ -319,7 +297,7 @@ SKKInstance::~SKKInstance ()
 void
 SKKInstance::init_key2kana (void)
 {
-    m_key2kana.set_table(skk_romakana_table);
+    m_key2kana.set_table(romakana_table);
     m_key2kana.append_table(romakana_ja_period_rule);
 }
 
