@@ -34,21 +34,12 @@
 #include <scim.h>
 #include <gtk/scimkeyselection.h>
 #include "scim_skk_prefs.h"
-
-#ifdef HAVE_GETTEXT
-#  include <libintl.h>
-#  define _(String) dgettext(GETTEXT_PACKAGE,String)
-#  define N_(String) (String)
-#else
-#  define _(String) (String)
-#  define N_(String) (String)
-#  define bindtextdomain(Package,Directory)
-#  define textdomain(domain)
-#  define bind_textdomain_codeset(domain,codeset)
-#endif
+#include "scim_skk_intl.h"
 
 using namespace scim;
 
+namespace scim_skk {
+
 #define scim_module_init skk_imengine_setup_LTX_scim_module_init
 #define scim_module_exit skk_imengine_setup_LTX_scim_module_exit
 
@@ -376,7 +367,7 @@ static KeyboardConfigData __config_keyboards_caret [] =
 };
 
 static FileConfigData __config_sysdict = {
-    N_("System Dictionary Path"),
+    N_("System Dictionary Path:"),
     SCIM_SKK_CONFIG_SYSDICT_DEFAULT,
     NULL,
     NULL,
@@ -448,7 +439,6 @@ create_combo_widget (const char *label_text, GtkWidget **widget,
 
     hbox = gtk_hbox_new (FALSE, 0);
     gtk_widget_show (hbox);
-    gtk_container_set_border_width (GTK_CONTAINER (hbox), 4);
 
     label = gtk_label_new (label_text);
     gtk_widget_show (label);
@@ -473,7 +463,7 @@ create_combo_widget (const char *label_text, GtkWidget **widget,
 static GtkWidget *
 create_color_button (ColorConfigData *entry)
 {
-    GtkWidget *hbox, *label;
+    GtkWidget *hbox, *label = NULL;
     if (!entry) return NULL;
 
     hbox = gtk_hbox_new (FALSE, 0);
@@ -549,9 +539,14 @@ create_options_page ()
     gtk_widget_show(hbox);
     __widget_annot_highlight = gtk_check_button_new_with_mnemonic(_("Highlight Annotation."));
     gtk_widget_show(__widget_annot_highlight);
-    gtk_box_pack_start(GTK_BOX(hbox), __widget_annot_highlight, TRUE, TRUE, 0);
+    gtk_box_pack_start(GTK_BOX(hbox), __widget_annot_highlight, FALSE, FALSE, 0);
+
+    alignment = gtk_alignment_new (0.5, 0.5, 1.0, 1.0);
+    gtk_alignment_set_padding (GTK_ALIGNMENT (alignment), 0, 0, 20, 0);
+    gtk_box_pack_start(GTK_BOX(hbox), alignment, FALSE, FALSE, 0);
+    gtk_widget_show(alignment);
     bgcolor_widgets = create_color_button(&annot_bgcolor);
-    gtk_box_pack_start(GTK_BOX(hbox), bgcolor_widgets, TRUE, TRUE, 0);
+    gtk_container_add (GTK_CONTAINER (alignment), bgcolor_widgets);
 
     /* view annot */
     __widget_annot_view = gtk_check_button_new_with_mnemonic (_("View Annotation."));
@@ -565,20 +560,19 @@ create_options_page ()
     gtk_widget_show(alignment);
 
     annot_widgets = gtk_vbox_new(FALSE, 0);
-    //gtk_box_pack_start(GTK_BOX(alignment), annot_widgets, FALSE, FALSE, 4);
     gtk_container_add(GTK_CONTAINER(alignment), annot_widgets);
     gtk_widget_show(annot_widgets);
     widget = create_combo_widget (_("Position of Annotation:"),
                                   &__widget_annot_pos,
                                   (gpointer) &__config_annot_pos,
                                   (gpointer) &annot_position);
-    gtk_box_pack_start (GTK_BOX (annot_widgets), widget, FALSE, FALSE, 0);
+    gtk_box_pack_start (GTK_BOX (annot_widgets), widget, FALSE, FALSE, 4);
 
     widget = create_combo_widget (_("Printed Annotation:"),
                                   &__widget_annot_target,
                                   (gpointer) &__config_annot_target,
                                   (gpointer) &annot_target);
-    gtk_box_pack_start (GTK_BOX (annot_widgets), widget, FALSE, FALSE, 0);
+    gtk_box_pack_start (GTK_BOX (annot_widgets), widget, FALSE, FALSE, 4);
 
     // Connect all signals.
     g_signal_connect ((gpointer) __widget_listsize, "value-changed",
@@ -630,7 +624,7 @@ create_dictionary_page ()
 
     /* user dictionary */
     widget            = gtk_hbox_new(FALSE, 0);
-    label             = gtk_label_new(_("User Dictionary Name"));
+    label             = gtk_label_new(_("User Dictionary Name:"));
     __widget_userdict = gtk_entry_new();
     gtk_widget_show(label);
     gtk_widget_show(__widget_userdict);
@@ -1096,6 +1090,7 @@ on_default_combo_changed (GtkEditable *editable,
     }
 }
 
+} /* namespace scim-skk */
 /*
 vi:ts=4:nowrap:ai:expandtab
 */
