@@ -42,9 +42,16 @@
 #define SCIM_SKK_CONFIG_SYSDICT          "/IMEngine/SKK/SysDict"
 #define SCIM_SKK_CONFIG_USERDICT         "/IMEngine/SKK/UserDict"
 
-#define SCIM_SKK_CONFIG_DICT_LISTSIZE     "/IMEngine/SKK/DictListSize"
-#define SCIM_SKK_CONFIG_DICT_VIEW_ANNOT   "/IMEngine/SKK/DictViewAnnot"
+#define SCIM_SKK_CONFIG_CANDVEC_SIZE      "/IMEngine/SKK/DictListSize"
 
+#define SCIM_SKK_CONFIG_ANNOT_VIEW     "/IMEngine/SKK/AnnotView"
+#define SCIM_SKK_CONFIG_ANNOT_POS      "/IMEngine/SKK/AnnotPos"
+#define SCIM_SKK_CONFIG_ANNOT_TARGET   "/IMEngine/SKK/AnnotTarget"
+
+#define SCIM_SKK_CONFIG_ANNOT_HIGHLIGHT "/IMEngine/SKK/AnnotHighlight"
+#define SCIM_SKK_CONFIG_ANNOT_BGCOLOR   "/IMEngine/SKK/AnnotBGColor"
+
+#define SCIM_SKK_CONFIG_IGNORE_RETURN   "/IMEngine/SKK/IgnoreReturn"
 
 /* default values */
 #define SCIM_SKK_CONFIG_KAKUTEI_KEY_DEFAULT          "Control+j"
@@ -68,6 +75,13 @@
 
 #define SCIM_SKK_CONFIG_SYSDICT_DEFAULT          "/usr/share/skk/SKK-JISYO.L"
 #define SCIM_SKK_CONFIG_USERDICT_DEFAULT         ".skk-scim-jisyo"
-#define SCIM_SKK_CONFIG_DICT_LISTSIZE_DEFAULT    4
-#define SCIM_SKK_CONFIG_DICT_VIEW_ANNOT_DEFAULT  true
+#define SCIM_SKK_CONFIG_CANDVEC_SIZE_DEFAULT      4
+#define SCIM_SKK_CONFIG_ANNOT_VIEW_DEFAULT    true
+#define SCIM_SKK_CONFIG_ANNOT_POS_DEFAULT     "auxwindow"
+#define SCIM_SKK_CONFIG_ANNOT_TARGET_DEFAULT  "all"
+
+#define SCIM_SKK_CONFIG_ANNOT_HIGHLIGHT_DEFAULT true
+#define SCIM_SKK_CONFIG_ANNOT_BGCOLOR_DEFAULT   "#a0ff80"
+
+#define SCIM_SKK_CONFIG_IGNORE_RETURN_DEFAULT   false
 #endif
